@@ -12,7 +12,8 @@ class Trusted:
     def __init__(self, owncloud_config):
         self.owncloud_config = owncloud_config
 
-    def trusted(self, domain_port):
+    def trusted(self, domain, port):
+        domain_port = "{0}:{1}".format(domain, port)
         with open(self.owncloud_config, "r") as f:
             config = f.read()
             new_config = convert_trusted_configuration(config, domain_port)
